<a id="aea.helpers.win32"></a>

# aea.helpers.win32

Helpers for Windows.

<a id="aea.helpers.win32.enable_ctrl_c_support"></a>

#### enable`_`ctrl`_`c`_`support

```python
def enable_ctrl_c_support() -> None
```

Enable ctrl+c support for aea.cli command to be tested on windows platform.

